@@ -5,26 +5,41 @@ OC.L10N.register(
     "Today" : "இன்று",
     "Week" : "வாரம்",
     "Month" : "மாதம்",
-    "Download" : "பதிவிறக்குக",
+    "List" : "List",
+    "Edit" : "தொகுக்க",
     "Delete" : "நீக்குக",
+    "Export" : "ஏற்றுமதி",
     "Share link" : "Share link",
     "can edit" : "தொகுக்க முடியும்",
     "New calendar" : "புதிய நாட்காட்டி",
+    "Name" : "பெயர்",
     "Cancel" : "இரத்து செய்க",
     "Actions" : "செயல்கள்",
-    "Email" : "மின்னஞ்சல்",
-    "Unknown" : "தெரியாத",
-    "never" : "ஒருபோதும்",
-    "Repeat" : "மீண்டும்",
+    "Location" : "இடம்",
+    "Description" : "விவரிப்பு",
+    "Add" : "சேர்க்க",
     "Monday" : "திங்கட்கிழமை",
-    "More" : "மேலதிக",
+    "Tuesday" : "செவ்வாய்க்கிழமை",
+    "Wednesday" : "புதன்கிழமை",
+    "Thursday" : "வியாழக்கிழமை",
+    "Friday" : "வெள்ளிக்கிழமை",
+    "Saturday" : "சனிக்கிழமை",
+    "Sunday" : "ஞாயிற்றுக்கிழமை",
     "Save" : "சேமிக்க ",
     "Update" : "இற்றைப்படுத்தல்",
+    "Your email address" : "உங்களுடைய மின்னஞ்சல் முகவரி",
+    "Email" : "மின்னஞ்சல்",
+    "Unknown" : "தெரியாத",
+    "Repeat" : "மீண்டும்",
+    "never" : "ஒருபோதும்",
+    "More" : "மேலதிக",
     "Personal" : "தனிப்பட்ட",
     "Details" : "விவரங்கள்",
     "Attendees" : "பங்கேற்பாளர்கள்",
     "Close" : "மூடுக",
-    "Location" : "இடம்",
-    "Description" : "விவரிப்பு"
+    "Prev" : "Prev",
+    "Next" : "அடுத்த",
+    "Other" : "மற்றவை",
+    "Birthday" : "பிறந்த நாள்"
 },
 "nplurals=2; plural=(n != 1);");
